=======
History
=======

0.1.0 (2018-11-07)
------------------

* First Alpha release on PyPI.


0.1.11 (2019-04-26)
-------------------
 * Added docker_image.docker_extra_options list feature

0.1.13 (2019-06-23)
-------------------
 * Handle errors in Jupytext conversions
 * aiscalator run subcommand exit code propagated to cli
 * Concurrent aiscalator run commands is possible
